==> blesta-5.10.2.zip: blesta/language/fr_fr/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.!error.unauthorized_access'] = 'Vous n\'êtes pas autorisé à accéder à cette ressource';
$lang['AppController.!error.invalid_csrf'] = 'Le jeton de formulaire n\'est pas valide.';
$lang['AppController.!success.license_updated'] = 'Votre licence a été revalidée avec succès. Veuillez vous connecter.';
$lang['AppController.!success.license_key_updated'] = 'Votre clé de licence a été mise à jour avec succès. Veuillez vous connecter.';
$lang['AppController.select.please'] = '-- Veuillez sélectionner --';
$lang['AppController.modal.text_close'] = 'Fermer';
$lang['AppController.modal.text_confirm'] = 'Veuillez confirmer';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.banners.client_manager'] = 'Vous gérez actuellement un compte qui vous a invité à le faire.';
$lang['AppController.banners.text_switch_back'] = 'Revenir à mon compte';
$lang['AppController.message.close'] = '×';
$lang['AppController.structure.text_myinfo'] = 'Mes informations';
$lang['AppController.structure.text_settings'] = 'Paramètres';
$lang['AppController.structure.text_logout'] = 'Se déconnecter';
$lang['AppController.structure.text_maintenance'] = 'Le mode maintenance est actuellement activé et les clients ne peuvent pas se connecter. Cliquez ici pour changer.';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.client_structure.staff_as_client_note'] = 'Retour au portail du personnel';
$lang['AppController.client_structure.default_title'] = 'Mon compte';
$lang['AppController.client_structure.text_return_to_portal'] = 'Retour au portail';
$lang['AppController.client_structure.text_logout'] = 'Se déconnecter';
$lang['AppController.client_structure.text_login'] = 'Se connecter';
$lang['AppController.client_structure.text_update_account'] = 'Gérer le compte';
$lang['AppController.client_structure.text_emails'] = 'Historique des courriels';
$lang['AppController.client_structure.text_accounts'] = 'Comptes de paiement';
$lang['AppController.client_structure.text_contacts'] = 'Contacts';
$lang['AppController.client_structure.text_managers'] = 'Gestionnaires';
$lang['AppController.dates.day_sun'] = 'Dimanche';
$lang['AppController.dates.day_mon'] = 'Lundi';
$lang['AppController.dates.day_tue'] = 'Mardi';
$lang['AppController.dates.day_wed'] = 'Mercredi';
$lang['AppController.dates.day_thu'] = 'Jeudi';
$lang['AppController.dates.day_fri'] = 'Vendredi';
$lang['AppController.dates.day_sat'] = 'Samedi';
$lang['AppController.dates.dayabbr_sun'] = 'Soleil';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_tue'] = 'Mar';
$lang['AppController.dates.dayabbr_wed'] = 'Mercredi';
$lang['AppController.dates.dayabbr_thur'] = 'Jeu';
$lang['AppController.dates.dayabbr_fri'] = 'Vendredi';
$lang['AppController.dates.dayabbr_sat'] = 'Samedi';
$lang['AppController.dates.month_jan'] = 'Janvier';
$lang['AppController.dates.month_feb'] = 'Février';
$lang['AppController.dates.month_mar'] = 'Mars';
$lang['AppController.dates.month_apr'] = 'Avril';
$lang['AppController.dates.month_may'] = 'Mai';
$lang['AppController.dates.month_jun'] = 'Juin';
$lang['AppController.dates.month_jul'] = 'Juillet';
$lang['AppController.dates.month_aug'] = 'Août';
$lang['AppController.dates.month_sep'] = 'Septembre';
$lang['AppController.dates.month_oct'] = 'Octobre';
$lang['AppController.dates.month_nov'] = 'Novembre';
$lang['AppController.dates.month_dec'] = 'Décembre';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.monthabbr_feb'] = 'Fév';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_apr'] = 'Avr';
$lang['AppController.dates.monthabbr_may'] = 'Mai';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_aug'] = 'Août';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_oct'] = 'Oct';
$lang['AppController.dates.monthabbr_nov'] = 'Nov';
$lang['AppController.dates.monthabbr_dec'] = 'Déc';
$lang['AppController.graphs.control_label.stacked'] = 'Empilés';
$lang['AppController.graphs.control_label.stream'] = 'Flux';
$lang['AppController.graphs.control_label.expanded'] = 'Élargi';
$lang['AppController.graphs.control_label.grouped'] = 'Regroupés';
$lang['AppController.graphs.label.total'] = 'Total';
$lang['AppController.sreader.dropdown'] = 'Basculer vers le bas';
$lang['AppController.sreader.navigation'] = 'Toggle Navigation';
$lang['AppController.dropzone.text'] = 'Déposez les fichiers ici pour les télécharger ou cliquez pour sélectionner les fichiers.';

==> blesta-5.11.4.zip: blesta/language/fr_fr/app_controller.php <==
<?php
/**
 * App Controller
 *
 * @package blesta
 * @subpackage blesta.language.fr_fr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AppController.lang.dir'] = 'ltr';
$lang['AppController.!error.unauthorized_access'] = 'Vous n\'êtes pas autorisé à accéder à cette ressource';
$lang['AppController.!error.invalid_csrf'] = 'Le jeton de formulaire n\'est pas valide.';
$lang['AppController.!success.license_updated'] = 'Votre licence a été revalidée avec succès. Veuillez vous connecter.';
$lang['AppController.!success.license_key_updated'] = 'Votre clé de licence a été mise à jour avec succès. Veuillez vous connecter.';
$lang['AppController.select.please'] = '-- Veuillez sélectionner --';
$lang['AppController.modal.text_close'] = 'Fermer';
$lang['AppController.modal.text_confirm'] = 'Veuillez confirmer';
$lang['AppController.tooltip.text'] = '?';
$lang['AppController.banners.client_manager'] = 'Vous gérez actuellement un compte qui vous a invité à le faire.';
$lang['AppController.banners.text_switch_back'] = 'Revenir à mon compte';
$lang['AppController.message.close'] = '×';
$lang['AppController.structure.text_myinfo'] = 'Mes informations';
$lang['AppController.structure.text_settings'] = 'Paramètres';
$lang['AppController.structure.text_logout'] = 'Se déconnecter';
$lang['AppController.structure.text_maintenance'] = 'Le mode maintenance est actuellement activé et les clients ne peuvent pas se connecter. Cliquez ici pour changer.';
$lang['AppController.structure.text_search_placeholder'] = '%1$s...';
$lang['AppController.client_structure.staff_as_client_note'] = 'Retour au portail du personnel';
$lang['AppController.client_structure.default_title'] = 'Mon compte';
$lang['AppController.client_structure.text_return_to_portal'] = 'Retour au portail';
$lang['AppController.client_structure.text_logout'] = 'Se déconnecter';
$lang['AppController.client_structure.text_login'] = 'Se connecter';
$lang['AppController.client_structure.text_update_account'] = 'Gérer le compte';
$lang['AppController.client_structure.text_emails'] = 'Historique des courriels';
$lang['AppController.client_structure.text_accounts'] = 'Comptes de paiement';
$lang['AppController.client_structure.text_contacts'] = 'Contacts';
$lang['AppController.client_structure.text_managers'] = 'Gestionnaires';
$lang['AppController.dates.day_sun'] = 'Dimanche';
$lang['AppController.dates.day_mon'] = 'Lundi';
$lang['AppController.dates.day_tue'] = 'Mardi';
$lang['AppController.dates.day_wed'] = 'Mercredi';
$lang['AppController.dates.day_thu'] = 'Jeudi';
$lang['AppController.dates.day_fri'] = 'Vendredi';
$lang['AppController.dates.day_sat'] = 'Samedi';
$lang['AppController.dates.dayabbr_sun'] = 'Soleil';
$lang['AppController.dates.dayabbr_mon'] = 'Mon';
$lang['AppController.dates.dayabbr_tue'] = 'Mar';
$lang['AppController.dates.dayabbr_wed'] = 'Mercredi';
$lang['AppController.dates.dayabbr_thur'] = 'Jeu';
$lang['AppController.dates.dayabbr_fri'] = 'Vendredi';
$lang['AppController.dates.dayabbr_sat'] = 'Samedi';
$lang['AppController.dates.month_jan'] = 'Janvier';
$lang['AppController.dates.month_feb'] = 'Février';
$lang['AppController.dates.month_mar'] = 'Mars';
$lang['AppController.dates.month_apr'] = 'Avril';
$lang['AppController.dates.month_may'] = 'Mai';
$lang['AppController.dates.month_jun'] = 'Juin';
$lang['AppController.dates.month_jul'] = 'Juillet';
$lang['AppController.dates.month_aug'] = 'Août';
$lang['AppController.dates.month_sep'] = 'Septembre';
$lang['AppController.dates.month_oct'] = 'Octobre';
$lang['AppController.dates.month_nov'] = 'Novembre';
$lang['AppController.dates.month_dec'] = 'Décembre';
$lang['AppController.dates.monthabbr_jan'] = 'Jan';
$lang['AppController.dates.monthabbr_feb'] = 'Fév';
$lang['AppController.dates.monthabbr_mar'] = 'Mar';
$lang['AppController.dates.monthabbr_apr'] = 'Avr';
$lang['AppController.dates.monthabbr_may'] = 'Mai';
$lang['AppController.dates.monthabbr_jun'] = 'Jun';
$lang['AppController.dates.monthabbr_jul'] = 'Jul';
$lang['AppController.dates.monthabbr_aug'] = 'Août';
$lang['AppController.dates.monthabbr_sep'] = 'Sep';
$lang['AppController.dates.monthabbr_oct'] = 'Oct';
$lang['AppController.dates.monthabbr_nov'] = 'Nov';
$lang['AppController.dates.monthabbr_dec'] = 'Déc';
$lang['AppController.graphs.control_label.stacked'] = 'Empilés';
$lang['AppController.graphs.control_label.stream'] = 'Flux';
$lang['AppController.graphs.control_label.expanded'] = 'Élargi';
$lang['AppController.graphs.control_label.grouped'] = 'Regroupés';
$lang['AppController.graphs.label.total'] = 'Total';
$lang['AppController.sreader.dropdown'] = 'Basculer vers le bas';
$lang['AppController.sreader.navigation'] = 'Toggle Navigation';
$lang['AppController.dropzone.text'] = 'Déposez les fichiers ici pour les télécharger ou cliquez pour sélectionner les fichiers.';
$lang['AppController.!error.client_unauthorized_access'] = 'Vous n\'avez pas l\'autorisation d\'accéder à cette ressource. Veuillez contacter le titulaire du compte principal pour demander l\'accès.';
